Crate kcr_chainsaw_kyverno_io

Crate kcr_chainsaw_kyverno_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the chainsaw.kyverno.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

chainsaw.kyverno.io/v1alpha1

  • Configuration
  • Test

chainsaw.kyverno.io/v1alpha2

  • Configuration
  • Test

Modules

v1alpha1
v1alpha2