This crate contains kube-rs compatible bindings for Kubernetes custom resources for the chainsaw.kyverno.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
chainsaw.kyverno.io/v1alpha1
ConfigurationTest
chainsaw.kyverno.io/v1alpha2
ConfigurationTest